@@ -254,16 +254,20 @@ class LanguageDefinition:
         to hard-code your syntax-definition. """
 
     def __init__(self, rules):
-        """ The constructor takes only one argument: A list of rules (i.e 
-            Pattern, KeywordList and String). """
-        self._grammar = rules
-        self._styles = dict()
+      """ The constructor takes only one argument: A list of rules (i.e 
+          Pattern, KeywordList and String). """
+      self._grammar = rules
+      self._styles = dict()
+      self.cache = {}
+
 
     def __call__(self, buf, start, end=None):
+      # if no end given -> end of buffer
+      if not end: end = buf.get_end_iter()
 
-        # if no end given -> end of buffer
-        if not end: end = buf.get_end_iter()
-
+      try:
+        return self.cache[(buf, start, end)]
+      except KeyError:
         mstart = mend = end
         mtag   = None
         txt = buf.get_slice(start, end)    
@@ -286,7 +290,8 @@ class LanguageDefinition:
                 mstart, mend = m
                 mtag = rule.tag_name
                 continue
-
+                
+        self.cache[(buf, start, end)] = (mstart, mend, mtag)
         return (mstart, mend, mtag)                
 
     def get_styles(self):
@@ -549,8 +554,8 @@ class CodeBuffer(gtk.TextBuffer):
         self.connect_after("insert-text", self._on_insert_text_hilight)
         self.connect("delete-range",self._on_delete_range_undo)
         self.connect_after("delete-range", self._on_delete_range_hilight)
-        self.connect('apply-tag', self._on_apply_tag)
-        self._apply_tags = False
+#        self.connect('apply-tag', self._on_apply_tag)
+#        self._apply_tags = False
 
     @property
     def can_undo(self):
@@ -805,20 +810,20 @@ class CodeBuffer(gtk.TextBuffer):
         if tagname:     #if something found
             tag = self.get_tag_table().lookup(tagname)
             if mstart.begins_tag(tag) and mend.ends_tag(tag) and not mstart.equal(start):
-                self._apply_tags = True
+#                self._apply_tags = True
                 self.remove_all_tags(start,mstart)
                 self.apply_tag_by_name("DEFAULT", start, mstart)
-                self._apply_tags = False
+#                self._apply_tags = False
                 return
 
         # remove all tags from start..mend (mend == buffer-end if no match)        
-        self._apply_tags=True
+#        self._apply_tags=True
         self.remove_all_tags(start, mend)
         # make start..mstart = DEFAUL (mstart == buffer-end if no match)
         if not start.equal(mstart):
             #_log_debug("Apply DEFAULT")
             self.apply_tag_by_name("DEFAULT", start, mstart)                
-        self._apply_tags=False
+#        self._apply_tags=False
         # nothing found -> finished
         if not tagname: 
            finished = True
@@ -826,9 +831,9 @@ class CodeBuffer(gtk.TextBuffer):
 
         # apply tag
         #_log_debug("Apply %s"%tagname)
-        self._apply_tags=True
+#        self._apply_tags=True
         self.apply_tag_by_name(tagname, mstart, mend)
-        self._apply_tags=False
+#        self._apply_tags=False
         start = mend
 
         if start == end: 
@@ -848,9 +853,9 @@ class CodeBuffer(gtk.TextBuffer):
         if self._lang_def:
             self.update_styles(self._lang_def.get_styles())
         # and ...
-        self._apply_tags = True
+#        self._apply_tags = True
         self.defer(self.update_syntax_idle,start.get_offset)
-        self._apply_tags = False
+#        self._apply_tags = False
 
     def update_styles(self, styles):
         """ Update styles. This method may be used to reset any styles at
