@@ -21,7 +21,7 @@ import pge_editor
 import os
 from subprocess import *
 import commands
-
+import gobject
 
 class Window(hildon.Window):
   def __init__(self,filepath=None,caller=None):
@@ -75,6 +75,17 @@ class Window(hildon.Window):
 
   def onShowFind(self, widget):
     self.findToolBar.show()
+    for fchild in self.findToolBar.get_children():
+      try:
+        for achild in fchild.get_children():
+          try:
+            for cchild in achild.get_children():
+              if type(cchild)==gtk.ComboBoxEntry:
+                self.set_focus(cchild.get_children()[0])                 
+          except:
+            pass
+      except:
+        pass
 
   def onHideFind(self, widget):
     self.findToolBar.hide()
@@ -211,9 +222,10 @@ class Window(hildon.Window):
       self.code_editor.reset_language(language)
 
   def open_dialog(self):
-      fsm = hildon.FileSystemModel()
+      #fsm = hildon.FileSystemModel()
       #fsm.set_property('visible-columns',7)
-      fc =hildon.FileChooserDialog(self, gtk.FILE_CHOOSER_ACTION_OPEN,fsm)
+      #fc =hildon.FileChooserDialog(self, gtk.FILE_CHOOSER_ACTION_OPEN,fsm)
+      fc = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_OPEN)
       fc.set_property('show-files',True)
       #fsm.set_property('visible-columns',7)
       #fc.set_extension('py')
